Install and configure a compute node
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

This section describes how to install and configure the
Kuryr-libnetwork on the compute node.

This section assumes that you already have a working OpenStack
environment with at least the following components installed:
Network, Identity.

.. note::

   The supported platforms are Ubuntu, openSUSE and SUSE Linux Enterprise,
   and Red Hat Enterprise Linux and CentOS. This guide currently provides
   installation stpes for Ubuntu. Other platforms will be introduced later.

.. toctree::

   compute-install-ubuntu.rst
